#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef PACKAGE
#undef VERSION
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LIBSM
#undef HAVE_PROGRAM_INVOCATION_SHORT_NAME
#undef HAVE_PROGRAM_INVOCATION_NAME
#undef GS_PATH
#undef LPR_PATH
#undef HAVE_GSTROKE
#undef ALPHA_PARAMS
#undef HAVE_XINERAMA
#undef BONOBO_DEBUG
